"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildRoutesFromController = void 0;
require("reflect-metadata");
const decoratos_1 = require("./decoratos");
function buildRoutesFromController(controller) {
    const rawBasePath = controller[decoratos_1.CONTROLLER_PATH_PROP];
    if (!rawBasePath)
        throw new Error('Provided object is not a valid controller');
    const basePath = rawBasePath.replace(/\/$/, '');
    const properties = Reflect.getMetadata(decoratos_1.metadataKey, controller) || [];
    const routes = {};
    for (const { method, path: rawResourcePath, propertyKey } of properties) {
        const resourcePath = rawResourcePath ? rawResourcePath.replace(/(^)([^/])/, '/$2').replace(/\/$/, '') : '';
        const path = basePath + resourcePath;
        routes[path] = routes[path] || { path };
        switch (method) {
            case 'GET':
                routes[path].get = controller[propertyKey];
                break;
            case 'POST':
                routes[path].post = controller[propertyKey];
                break;
            case 'PUT':
                routes[path].put = controller[propertyKey];
                break;
            case 'DELETE':
                routes[path].delete = controller[propertyKey];
                break;
        }
    }
    return Object.values(routes);
}
exports.buildRoutesFromController = buildRoutesFromController;
